@@ -174,7 +174,7 @@ class CertificateAuthority(object):
         oid=_SUBJECT_OID_DICT[key],
         value=value,
       )
-      for key, value in dict(ca_subject_dict).iteritems()
+      for key, value in dict(ca_subject_dict).items()
     ])
     self._ca_extension_list = list(ca_extension_list)
     if ca_life_period < 3:
@@ -264,8 +264,10 @@ class CertificateAuthority(object):
       ).digest),
       override_limits=override_limits,
     )
-    if requested_amount is not None and \
-    requested_amount <= self._auto_sign_csr_amount:
+    if (
+      requested_amount is not None and
+      requested_amount <= self._auto_sign_csr_amount
+    ):
       # if allowed to sign this certificate automaticaly
       self._createCertificate(csr_id, auto_signed=_AUTO_SIGNED_YES)
     return csr_id
@@ -678,7 +680,7 @@ class CertificateAuthority(object):
       self.getCACertificateList(),
       crl_list=[
         x509.load_pem_x509_crl(x, _cryptography_backend)
-        for x in self.getCertificateRevocationListDict().itervalues()
+        for x in self.getCertificateRevocationListDict().values()
       ],
     )
     self._storage.revoke(
@@ -730,7 +732,7 @@ class CertificateAuthority(object):
       self.getCACertificateList(),
       crl_list=[
         x509.load_pem_x509_crl(x, _cryptography_backend)
-        for x in self.getCertificateRevocationListDict().itervalues()
+        for x in self.getCertificateRevocationListDict().values()
       ],
     )
     return self._createCertificate(
@@ -850,7 +852,7 @@ class UserCertificateAuthority(CertificateAuthority):
     ca_cert_list = self.getCACertificateList()
     crl_list = [
       x509.load_pem_x509_crl(x, _cryptography_backend)
-      for x in self.getCertificateRevocationListDict().itervalues()
+      for x in self.getCertificateRevocationListDict().values()
     ]
     signing_key = os.urandom(32)
     symetric_key = os.urandom(32)
