@@ -25,7 +25,11 @@ from __future__ import absolute_import, print_function
 import argparse
 from binascii import hexlify
 import datetime
-import httplib
+try:
+  import http.client as http_client
+except ImportError: # pragma: no cover
+  # BBB: py2.7
+  import httplib as http_client
 import json
 import os
 import socket
@@ -42,6 +46,9 @@ from .client import (
   HTTPSOnlyCaucaseClient,
 )
 
+if sys.version_info[0] >= 3: # pragma: no cover
+  unicode = str
+
 class RetryingCaucaseClient(CaucaseClient):
   """
   Similar to CaucaseClient, but retries indefinitely on http & socket errors.
@@ -69,10 +76,10 @@ class RetryingCaucaseClient(CaucaseClient):
         # but so do errors which are either sign of code bugs
         # (ImproperConnectionState) or sign of garbage values provided by
         # caller/user, and these should be let through.
-        httplib.BadStatusLine,
-        httplib.LineTooLong,
-        httplib.UnknownProtocol,
-        httplib.IncompleteRead,
+        http_client.BadStatusLine,
+        http_client.LineTooLong,
+        http_client.UnknownProtocol,
+        http_client.IncompleteRead,
       ) as exception:
         connection.close() # Resets HTTPConnection state machine.
         # Note: repr(str(exception)) is nicer than repr(exception), without
@@ -156,12 +163,12 @@ class CLICaucaseClient(object):
       try:
         crt_pem = self._client.getCertificate(crt_id)
       except CaucaseError as e:
-        if e.args[0] != httplib.NOT_FOUND:
+        if e.args[0] != http_client.NOT_FOUND:
           raise
         try:
           self._client.getCertificateSigningRequest(crt_id)
         except CaucaseError as e:
-          if e.args[0] != httplib.NOT_FOUND:
+          if e.args[0] != http_client.NOT_FOUND:
             raise
           self._print(crt_id, 'not found - maybe CSR was rejected ?')
           error = True
@@ -707,8 +714,8 @@ def probe(argv=None):
   )
   ca_url, = parser.parse_args(argv).ca_url
   cas_url = ca_url + '/cas'
-  with CaucaseClient(ca_url=cas_url) as http_client:
-    http_ca_pem = http_client.getCACertificate()
+  with CaucaseClient(ca_url=cas_url) as caucase_client:
+    http_ca_pem = caucase_client.getCACertificate()
     with HTTPSOnlyCaucaseClient(
       ca_url=cas_url,
       ca_crt_pem_list=[http_ca_pem],
@@ -716,7 +723,7 @@ def probe(argv=None):
       https_ca_pem = https_client.getCACertificate()
     # Retrieve again in case there was a renewal between both calls - we do
     # not expect 2 renewals in very short succession.
-    http2_ca_pem = http_client.getCACertificate()
+    http2_ca_pem = caucase_client.getCACertificate()
   if https_ca_pem not in (http_ca_pem, http2_ca_pem):
     raise ValueError('http and https do not serve the same caucase database')
 
@@ -878,7 +885,7 @@ def updater(argv=None, until=utils.until):
         try:
           crt_pem = client.getCertificate(csr_id)
         except CaucaseError as e:
-          if e.args[0] != httplib.NOT_FOUND:
+          if e.args[0] != http_client.NOT_FOUND:
             raise
           # If server does not know our CSR anymore, getCSR will raise.
           # If it does, we were likely rejected, so exit by letting exception
