@@ -22,10 +22,16 @@
 Caucase - Certificate Authority for Users, Certificate Authority for SErvices
 """
 from __future__ import absolute_import
-import httplib
+try:
+  import http.client as http_client
+except ImportError: # BBB: py2.7
+  import httplib as http_client
 import json
 import ssl
-from urlparse import urlparse
+try:
+  from urllib.parse import urlparse
+except ImportError: # BBB: py2.7
+  from urlparse import urlparse
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 import cryptography.exceptions
@@ -68,8 +74,8 @@ class CaucaseClient(object):
 
   Expose caucase REST API as pythonic methods.
   """
-  HTTPConnection = httplib.HTTPConnection
-  HTTPSConnection = httplib.HTTPSConnection
+  HTTPConnection = http_client.HTTPConnection
+  HTTPSConnection = http_client.HTTPSConnection
 
   @classmethod
   def updateCAFile(cls, url, ca_crt_path):
@@ -153,7 +159,7 @@ class CaucaseClient(object):
       server_crl_list = client.getCertificateRevocationListList()
     for ca_key_id, crl_pem in _asCRLDict(
       crl_pem_list=server_crl_list,
-    ).iteritems():
+    ).items():
       updated |= local_crl_dict.pop(ca_key_id, None) != crl_pem
     updated |= bool(local_crl_dict)
     if updated:
