@@ -33,12 +33,18 @@ import itertools
 import json
 import os
 import socket
-from SocketServer import ThreadingMixIn
+try:
+  from socketserver import ThreadingMixIn
+except ImportError: # BBB: py2.7
+  from SocketServer import ThreadingMixIn
 import ssl
 import sys
 import tempfile
 from threading import Thread
-from urlparse import urlparse, urlunsplit
+try:
+  from urllib.parse import urlparse, urlunsplit
+except ImportError: # BBB: py2.7
+  from urlparse import urlparse, urlunsplit
 from wsgiref.simple_server import make_server, WSGIServer
 import ipaddress
 from cryptography import x509
@@ -120,7 +126,7 @@ class ThreadingWSGIServer(ThreadingMixIn, WSGIServer):
     - intercept EBADF on shutdown if select is interrupted:
     """
     try:
-      return WSGIServer.serve_forever(self, *args, **kw)
+      WSGIServer.serve_forever(self, *args, **kw)
     except socket.error as exception: # pragma: no cover
       # Workaround for the following unhandled error:
       # Traceback (most recent call last):
@@ -147,7 +153,7 @@ class ThreadingWSGIServer(ThreadingMixIn, WSGIServer):
 
 def _buildQuoteCharList():
   # All chars considered guilty
-  result = ['\\x%02x' % x for x in xrange(256)]
+  result = ['\\x%02x' % x for x in range(256)]
   # Exception for non-printable whitespaces.
   result[ord('\b')] = '\\b'
   result[ord('\n')] = '\\n'
@@ -155,7 +161,7 @@ def _buildQuoteCharList():
   result[ord('\t')] = '\\t'
   result[ord('\v')] = '\\v'
   # Exception for printable chars
-  for x in xrange(0x20, 0x7f):
+  for x in range(0x20, 0x7f):
     result[x] = chr(x)
   # Exception in the exception: chars which need escapement
   result[ord('\\')] = '\\\\'
@@ -1056,7 +1062,7 @@ def manage(argv=None, stdout=sys.stdout):
       db_path,
       table_prefix='cas',
     )
-    for identifier, ca_pair in import_ca_dict.iteritems():
+    for identifier, ca_pair in import_ca_dict.items():
       found_from = ', '.join(ca_pair['from'])
       crt = ca_pair['crt']
       if crt is None:
