@@ -48,6 +48,24 @@ from .exceptions import (
   NotJSON,
 )
 
+if sys.version_info[0] >= 3: # pragma: no cover
+  unicode = str
+
+  def getAuthorityKeyIdentifier(cert):
+    """
+    Returns the authority key identifier of given certificate.
+    """
+    # pylint: disable=no-member
+    return int.from_bytes(_getAuthorityKeyIdentifier(cert), 'big')
+    # pylint: enable=no-member
+else: # pragma: no cover
+  # BBB: py2.7
+  def getAuthorityKeyIdentifier(cert):
+    """
+    Returns the authority key identifier of given certificate.
+    """
+    return int(_getAuthorityKeyIdentifier(cert).encode('hex'), 16)
+
 DEFAULT_DIGEST_LIST = ('sha256', 'sha384', 'sha512')
 DEFAULT_DIGEST = DEFAULT_DIGEST_LIST[0]
 DEFAULT_DIGEST_CLASS = getattr(hashes, DEFAULT_DIGEST.upper())
@@ -225,7 +243,7 @@ def _savePEMListToDirectory(dir_path, pem_list, pem_loader, extension):
     if not os.path.islink(filepath) and filename in pem_dict:
       try:
         # pylint: disable=unbalanced-tuple-unpacking
-        file_pem_item, = _getPEMTypeDict(filepath).itervalues()
+        file_pem_item, = _getPEMTypeDict(filepath).values()
         # pylint: enable=unbalanced-tuple-unpacking
       # pylint: disable=broad-except
       except Exception:
@@ -239,7 +257,7 @@ def _savePEMListToDirectory(dir_path, pem_list, pem_loader, extension):
     else:
       # Unknown file (ex: expired certificate), or a symlink to a file: delete
       os.unlink(filepath)
-  for filename, pem_item in pem_dict.iteritems():
+  for filename, pem_item in pem_dict.items():
     filepath = os.path.join(dir_path, filename)
     with open(filepath, 'wb') as pem_file:
       pem_file.write(pem_item)
@@ -578,21 +596,6 @@ def _getAuthorityKeyIdentifier(cert):
     x509.AuthorityKeyIdentifier,
   ).value.key_identifier
 
-if sys.version_info < (3, ): # pragma: no cover
-  def getAuthorityKeyIdentifier(cert):
-    """
-    Returns the authority key identifier of given certificate.
-    """
-    return int(_getAuthorityKeyIdentifier(cert).encode('hex'), 16)
-else: # pragma: no cover
-  def getAuthorityKeyIdentifier(cert):
-    """
-    Returns the authority key identifier of given certificate.
-    """
-    # pylint: disable=no-member
-    return int.from_bytes(_getAuthorityKeyIdentifier(cert), 'big')
-    # pylint: enable=no-member
-
 EPOCH = datetime.datetime(1970, 1, 1)
 def datetime2timestamp(value):
   """
