@@ -22,24 +22,35 @@
 Caucase - Certificate Authority for Users, Certificate Authority for SErvices
 """
 from __future__ import absolute_import
-from Cookie import SimpleCookie, CookieError
-import httplib
+try: # pragma: no cover
+  from http.cookies import SimpleCookie, CookieError
+  import http.client as http_client
+except ImportError: # pragma: no cover
+  # BBB: py2.7
+  from Cookie import SimpleCookie, CookieError
+  import httplib as http_client
 import json
 import os
 import sys
 import threading
 import time
-from urllib import quote, urlencode
-from urlparse import parse_qs
+try: # pragma: no cover
+  from urllib.parse import quote, urlencode
+  from urllib.parse import parse_qs
+except ImportError: # pragma: no cover
+  # BBB: py2.7
+  from urllib import quote, urlencode
+  from urlparse import parse_qs
 from wsgiref.util import application_uri, request_uri
 import jwt
 from . import utils
 from . import exceptions
 
 # pylint: disable=import-error,no-name-in-module
-if sys.version_info >= (3, ): # pragma: no cover
+if sys.version_info[0] >= 3: # pragma: no cover
   from html import escape
 else: # pragma: no cover
+  # BBB: py2.7
   from cgi import escape
 # pylint: enable=import-error,no-name-in-module
 
@@ -83,13 +94,13 @@ CORS_COOKIE_ORIGIN_KEY = 'o' # Prevent an origin from stealing another's token.
 A_YEAR_IN_SECONDS = 60 * 60 * 24 * 365 # Roughly a year
 
 def _getStatus(code):
-  return '%i %s' % (code, httplib.responses[code])
+  return '%i %s' % (code, http_client.responses[code])
 
 class ApplicationError(Exception):
   """
   WSGI HTTP error base class.
   """
-  status = _getStatus(httplib.INTERNAL_SERVER_ERROR)
+  status = _getStatus(http_client.INTERNAL_SERVER_ERROR)
   _response_headers = []
 
   @property
@@ -103,13 +114,13 @@ class BadRequest(ApplicationError):
   """
   HTTP bad request error
   """
-  status = _getStatus(httplib.BAD_REQUEST)
+  status = _getStatus(http_client.BAD_REQUEST)
 
 class Unauthorized(ApplicationError):
   """
   HTTP unauthorized error
   """
-  status = _getStatus(httplib.UNAUTHORIZED)
+  status = _getStatus(http_client.UNAUTHORIZED)
 
 class SSLUnauthorized(Unauthorized):
   """
@@ -136,19 +147,19 @@ class Forbidden(ApplicationError):
   """
   HTTP forbidden error
   """
-  status = _getStatus(httplib.FORBIDDEN)
+  status = _getStatus(http_client.FORBIDDEN)
 
 class NotFound(ApplicationError):
   """
   HTTP not found error
   """
-  status = _getStatus(httplib.NOT_FOUND)
+  status = _getStatus(http_client.NOT_FOUND)
 
 class BadMethod(ApplicationError):
   """
   HTTP bad method error
   """
-  status = _getStatus(httplib.METHOD_NOT_ALLOWED)
+  status = _getStatus(http_client.METHOD_NOT_ALLOWED)
 
   def __init__(self, allowed_list):
     super(BadMethod, self).__init__(allowed_list)
@@ -160,13 +171,13 @@ class Conflict(ApplicationError):
   """
   HTTP conflict
   """
-  status = _getStatus(httplib.CONFLICT)
+  status = _getStatus(http_client.CONFLICT)
 
 class TooLarge(ApplicationError):
   """
   HTTP too large error
   """
-  status = _getStatus(httplib.REQUEST_ENTITY_TOO_LARGE)
+  status = _getStatus(http_client.REQUEST_ENTITY_TOO_LARGE)
 
 class InsufficientStorage(ApplicationError):
   """
@@ -175,18 +186,18 @@ class InsufficientStorage(ApplicationError):
   # python2.7's httplib lacks the textual description for 507, although it
   # has the constant.
   # And modern pylint on python3 complain that
-  # http.client.INSUFFICIENT_STORAGE, an enum item, is not suitable for %i
+  # http_client.INSUFFICIENT_STORAGE, an enum item, is not suitable for %i
   # (spoiler: it is suitable).
   # Also, older pylint (last version suppoting 2.7 ?) does not support
   # bad-string-format-type but does not detect anything wrong here.
   # pylint: disable=bad-string-format-type
-  status = '%i Insufficient Storage' % (httplib.INSUFFICIENT_STORAGE, )
+  status = '%i Insufficient Storage' % (http_client.INSUFFICIENT_STORAGE, )
   # pylint: enable=bad-string-format-type
 
-STATUS_OK = _getStatus(httplib.OK)
-STATUS_CREATED = _getStatus(httplib.CREATED)
-STATUS_NO_CONTENT = _getStatus(httplib.NO_CONTENT)
-STATUS_FOUND = _getStatus(httplib.FOUND)
+STATUS_OK = _getStatus(http_client.OK)
+STATUS_CREATED = _getStatus(http_client.CREATED)
+STATUS_NO_CONTENT = _getStatus(http_client.NO_CONTENT)
+STATUS_FOUND = _getStatus(http_client.FOUND)
 MAX_BODY_LENGTH = 10 * 1024 * 1024 # 10 MB
 
 class CORSTokenManager(object):
@@ -571,7 +582,7 @@ class Application(object):
               # CORS headers added, add more
               self._optionAddCORSHeaders(method_dict, cors_header_list)
           else:
-            raise BadMethod(method_dict.keys() + ['OPTIONS'])
+            raise BadMethod(list(method_dict.keys()) + ['OPTIONS'])
         else:
           subpath = action_dict.get('subpath', SUBPATH_FORBIDDEN)
           if (
@@ -680,7 +691,7 @@ class Application(object):
         trusted_cert_list=ca_list,
         crl_list=[
           utils.load_crl(x, ca_list)
-          for x in self._cau.getCertificateRevocationListDict().itervalues()
+          for x in self._cau.getCertificateRevocationListDict().values()
         ],
       )
     except (exceptions.CertificateVerificationError, ValueError):
@@ -731,7 +742,7 @@ class Application(object):
       ', '.join(
         [
           x
-          for x, y in method_dict.iteritems()
+          for x, y in method_dict.items()
           if y.get('cors') is not CORS_POLICY_ALWAYS_DENY
         ] + ['OPTIONS'],
       ),
@@ -868,14 +879,14 @@ class Application(object):
     )]
     while routing_dict_list:
       routing_path, routing_dict = routing_dict_list.pop()
-      for component, path_entry_dict in routing_dict.iteritems():
+      for component, path_entry_dict in routing_dict.items():
         component_path = routing_path + '/' + component
         if recurse and 'routing' in path_entry_dict:
           routing_dict_list.append((
             component_path,
             path_entry_dict['routing'],
           ))
-        for method, action_dict in path_entry_dict['method'].iteritems():
+        for method, action_dict in path_entry_dict['method'].items():
           for action in action_dict.get('descriptor', ()):
             descriptor_dict = {
               'title': action['title'],
@@ -1000,7 +1011,7 @@ class Application(object):
       except KeyError:
         raise NotFound
     else:
-      crl = b'\n'.join(crl_dict.itervalues())
+      crl = b'\n'.join(crl_dict.values())
     return self._returnFile(crl, 'application/pkix-crl')
 
   def getCSR(self, context, environ, subpath):
